==> webgui_7.7.30.orig.tar.gz: WebGUI/lib/WebGUI/Help/Asset_StoryTopic.pm <==
package WebGUI::Help::Asset_StoryTopic;
use strict;

our $HELP = {

    'view template' => {
        title => 'view template',
        body  => '',
        isa   => [
            {   namespace => "Asset_StoryTopic",
                tag       => "storytopic asset template variables"
            },
            {   namespace => "Asset_Template",
                tag       => "template variables"
            },
            {   namespace => "Asset",
                tag       => "asset template"
            },
        ],
        fields    => [],
        variables => [
            { name => 'standAlone' },
            { name => 'story_loop',
              variables => [
                { name => 'url' },
                { name => 'title' },
                { name => 'creationDate' },
                { name => 'deleteIcon' },
                { name => 'editIcon' },
              ],
            },
            { name => 'topStoryTitle'        },
            { name => 'topStorySubtitle'     },
            { name => 'topStoryUrl'          },
            { name => 'topStoryCreationDate' },
            { name => 'topStoryImageUrl'     },
            { name => 'topStoryImageCaption' },
            { name => 'topStoryImageByline'  },
            { name => 'topStoryImageAlt'     },
            { name => 'topStoryImageTitle'   },
            { name => 'topStoryImageLink'    },
            { name => 'rssUrl'               },
            { name => 'atomUrl'              },
        ],
        related => []
    },

    'storytopic asset template variables' => {
        private => 1,
        title   => 'storytopic asset template variables title',
        body    => '',
        isa     => [
            {   namespace => "Asset_Wobject",
                tag       => "wobject template variables"
            },
        ],
        fields    => [],
        variables => [
        ],
        related => []
    },


};

1;

==> webgui_7.9.18.orig.tar.gz: WebGUI/lib/WebGUI/Help/Asset_StoryTopic.pm <==
package WebGUI::Help::Asset_StoryTopic;
use strict;

our $HELP = {

    'view template' => {
        title => 'view template',
        body  => '',
        isa   => [
            {   namespace => "Asset_StoryTopic",
                tag       => "storytopic asset template variables"
            },
            {   namespace => "Asset_Template",
                tag       => "template variables"
            },
            {   namespace => "Asset",
                tag       => "asset template"
            },
        ],
        fields    => [],
        variables => [
            { name => 'standAlone' },
            { name => 'story_loop',
              variables => [
                { name => 'url' },
                { name => 'title' },
                { name => 'creationDate' },
                { name => 'deleteIcon' },
                { name => 'editIcon' },
              ],
            },
            { name => 'topStoryDeleteIcon',
              description => 'deleteIcon', },
            { name => 'topStoryEditIcon',
              description => 'editIcon', },
            { name => 'topStoryTitle'        },
            { name => 'topStorySubtitle'     },
            { name => 'topStoryUrl'          },
            { name => 'topStoryCreationDate' },
            { name => 'topStoryImageUrl'     },
            { name => 'topStoryImageCaption' },
            { name => 'topStoryImageByline'  },
            { name => 'topStoryImageAlt'     },
            { name => 'topStoryImageTitle'   },
            { name => 'topStoryImageLink'    },
            { name => 'rssUrl'               },
            { name => 'atomUrl'              },
        ],
        related => []
    },

    'storytopic asset template variables' => {
        private => 1,
        title   => 'storytopic asset template variables title',
        body    => '',
        isa     => [
            {   namespace => "Asset_Wobject",
                tag       => "wobject template variables"
            },
        ],
        fields    => [],
        variables => [
        ],
        related => []
    },


};

1;
